#############
3D Slicer GUI
#############

`3D Slicer <https://www.slicer.org/>`_ is an open source software platform for
medical image informatics, image processing,
and three-dimensional visualization.

TorchIO provides a 3D Slicer extension for quick experimentation and
visualization of the package features.

.. The TorchIO extension can be installed using the
.. `Extensions Manager <https://www.slicer.org/wiki/Documentation/4.10/SlicerApplication/ExtensionsManager>`_.

The code and installation instructions are available on
`GitHub <https://github.com/fepegar/SlicerTorchIO>`_.

Modules
=======

TorchIO Transforms
------------------

This module can be used to quickly visualize the effect of each transform
parameter.
That way, users can have an intuitive feeling of what the output
of a transform looks like without any coding at all.

.. image:: https://raw.githubusercontent.com/fepegar/SlicerTorchIO/master/Screenshots/TorchIO.png
    :alt: TorchIO Transforms module for 3D Slicer
